@@ -55,7 +55,7 @@ static METHOD knh__System_setIn(Ctx *ctx, knh_sfp_t *sfp)
 {
 	if(knh_Context_isAdmin(ctx)) {
 		if(IS_NULL(sfp[1].o)) {
-			KNH_SETv(ctx, DP(ctx->sys)->in, konoha_geClassTableDefaultValue(ctx, CLASS_InputStream));
+			KNH_SETv(ctx, DP(ctx->sys)->in, konoha_getClassDefaultValue(ctx, CLASS_InputStream));
 		}
 		else {
 			KNH_SETv(ctx, DP(ctx->sys)->in, sfp[1].o);
@@ -79,7 +79,7 @@ static METHOD knh__System_setOut(Ctx *ctx, knh_sfp_t *sfp)
 {
 	if(knh_Context_isAdmin(ctx)) {
 		if(IS_NULL(sfp[1].o)) {
-			KNH_SETv(ctx, DP(ctx->sys)->out, konoha_geClassTableDefaultValue(ctx, CLASS_OutputStream));
+			KNH_SETv(ctx, DP(ctx->sys)->out, konoha_getClassDefaultValue(ctx, CLASS_OutputStream));
 		}
 		else {
 			KNH_SETv(ctx, DP(ctx->sys)->out, sfp[1].o);
@@ -103,7 +103,7 @@ static METHOD knh__System_setErr(Ctx *ctx, knh_sfp_t *sfp)
 {
 	if(knh_Context_isAdmin(ctx)) {
 		if(IS_NULL(sfp[1].o)) {
-			KNH_SETv(ctx, DP(ctx->sys)->err, konoha_geClassTableDefaultValue(ctx, CLASS_OutputStream));
+			KNH_SETv(ctx, DP(ctx->sys)->err, konoha_getClassDefaultValue(ctx, CLASS_OutputStream));
 		}
 		else {
 			KNH_SETv(ctx, DP(ctx->sys)->err, sfp[1].o);
@@ -208,7 +208,7 @@ static METHOD knh__Context_setIn(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_ASSERT(ctx == (Ctx*)sfp[0].o);
 	if(IS_NULL(sfp[1].o)) {
-		KNH_SETv(ctx, ((Context*)ctx)->in, konoha_geClassTableDefaultValue(ctx, CLASS_InputStream));
+		KNH_SETv(ctx, ((Context*)ctx)->in, konoha_getClassDefaultValue(ctx, CLASS_InputStream));
 	}
 	else {
 		KNH_SETv(ctx, ((Context*)ctx)->in, sfp[1].o);
@@ -223,7 +223,7 @@ static METHOD knh__Context_setOut(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_ASSERT(ctx == (Ctx*)sfp[0].o);
 	if(IS_NULL(sfp[1].o)) {
-		KNH_SETv(ctx, ((Context*)ctx)->out, konoha_geClassTableDefaultValue(ctx, CLASS_OutputStream));
+		KNH_SETv(ctx, ((Context*)ctx)->out, konoha_getClassDefaultValue(ctx, CLASS_OutputStream));
 	}
 	else {
 		KNH_SETv(ctx, ((Context*)ctx)->out, sfp[1].o);
@@ -238,7 +238,7 @@ static METHOD knh__Context_setErr(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_ASSERT(ctx == (Ctx*)sfp[0].o);
 	if(IS_NULL(sfp[1].o)) {
-		KNH_SETv(ctx, ((Context*)ctx)->err, konoha_geClassTableDefaultValue(ctx, CLASS_OutputStream));
+		KNH_SETv(ctx, ((Context*)ctx)->err, konoha_getClassDefaultValue(ctx, CLASS_OutputStream));
 	}
 	else {
 		KNH_SETv(ctx, ((Context*)ctx)->err, sfp[1].o);
