@@ -142,7 +142,7 @@ int knh_dbcurnext__sqlite3(Ctx *ctx, knh_dbcur_t *dbcur, struct knh_ResultSet_t
 			int type = sqlite3_column_type(stmt, i);
 			switch(type) {
 				case SQLITE_INTEGER: {
-					knh_ResultSet_setInt(ctx, rs, i, (knh_integer_t)sqlite3_column_int64(stmt, i));
+					knh_ResultSet_setInt(ctx, rs, i, (knh_int_t)sqlite3_column_int64(stmt, i));
 					break;
 				}
 				case SQLITE_FLOAT: {
