@@ -69,7 +69,7 @@ static char* knh_token_array_tochar[] = {
     "catch",  /* catch */ 
     "finally",  /* finally */ 
     "throw",  /* throw */ 
-    "local",  /* local */ 
+    "register",  /* register */ 
     "print",  /* print */ 
     "assert",  /* assert */ 
     "{",  /* BRACE */ 
@@ -199,7 +199,7 @@ static knh_methodn_t knh_token_array_tomethodn[] = {
     METHODN_NONAME,  /* catch */ 
     METHODN_NONAME,  /* finally */ 
     METHODN_NONAME,  /* throw */ 
-    METHODN_NONAME,  /* local */ 
+    METHODN_NONAME,  /* register */ 
     METHODN_NONAME,  /* print */ 
     METHODN_NONAME,  /* assert */ 
     METHODN_NONAME,  /* BRACE */ 
@@ -329,7 +329,7 @@ static int knh_token_array_getOpPriority[] = {
     0,  /* catch */ 
     0,  /* finally */ 
     0,  /* throw */ 
-    0,  /* local */ 
+    0,  /* register */ 
     0,  /* print */ 
     0,  /* assert */ 
     99,  /* BRACE */ 
@@ -459,7 +459,7 @@ static int knh_token_array_getOpSize[] = {
     0,  /* catch */ 
     0,  /* finally */ 
     0,  /* throw */ 
-    0,  /* local */ 
+    0,  /* register */ 
     0,  /* print */ 
     0,  /* assert */ 
     0,  /* BRACE */ 
@@ -589,7 +589,7 @@ static knh_bool_t knh_token_array_isEndOfStmt[] = {
     1,  /* catch */ 
     1,  /* finally */ 
     1,  /* throw */ 
-    1,  /* local */ 
+    1,  /* register */ 
     1,  /* print */ 
     1,  /* assert */ 
     0,  /* BRACE */ 
@@ -696,10 +696,6 @@ Token *new_Token__parse(Ctx *ctx, knh_flag_t flag, InputStream *in, knh_bytes_t
     knh_bytes_t t = token;
     knh_token_t tt = ((knh_token_t)-1);
     L_TAIL:;
-    //if(t.buf[0] == '.' && islower(t.buf[1])) {   /* .name   => name */
-        //flag |= KNH_FLAG_TKF_TOPDOT;
-        //t.buf++; t.len--;
-    //}
     if(isalpha(t.buf[0])) {
         if(t.buf[t.len-2]=='.' && t.buf[t.len-1]=='.') {
             flag |= KNH_FLAG_TKF_ITERATORTYPE;
@@ -872,7 +868,6 @@ Token *new_Token__parse(Ctx *ctx, knh_flag_t flag, InputStream *in, knh_bytes_t
         if(ISB(t, "int")) { t = STEXT("Int!"); goto L_TAIL; }
     break;
     case 'l':
-        if(ISB(t, "local")) { tt = TT_LOCAL; break; }
         if(ISB(t, "long")) { t = STEXT("Int!"); goto L_TAIL; }
     break;
     case 'm':
@@ -895,6 +890,7 @@ Token *new_Token__parse(Ctx *ctx, knh_flag_t flag, InputStream *in, knh_bytes_t
     break;
     case 'r':
         if(ISB(t, "return")) { tt = TT_RETURN; break; }
+        if(ISB(t, "register")) { tt = TT_REGISTER; break; }
     break;
     case 's':
         if(ISB(t, "switch")) { tt = TT_SWITCH; break; }
@@ -1060,7 +1056,7 @@ static char* knh_stmt_array_tochar[] = {
     "throw",  /* throw */ 
     "err",  /* err */ 
     "let",  /* let */ 
-    "local",  /* local */ 
+    "register",  /* register */ 
     "letmulti",  /* letmulti */ 
     "new",  /* new */ 
     "mapcast",  /* mapcast */ 
@@ -1131,7 +1127,7 @@ static size_t knh_stmt_array_size[] = {
     1,  /* throw */ 
     1,  /* err */ 
     2,  /* let */ 
-    5,  /* local */ 
+    5,  /* register */ 
     5,  /* letmulti */ 
     7,  /* new */ 
     3,  /* mapcast */ 
@@ -1203,7 +1199,7 @@ static int knh_stmt_array_isExpr[] = {
     0,  /* throw */ 
     0,  /* err */ 
     1,  /* let */ 
-    0,  /* local */ 
+    0,  /* register */ 
     0,  /* letmulti */ 
     1,  /* new */ 
     1,  /* mapcast */ 
