@@ -220,13 +220,14 @@ void knh_ObjectField_traverse(Ctx *ctx, knh_ObjectField_t *of, knh_ftraverse ftr
 		knh_ClassStruct_t *cs = ctx->share->ClassTable[cid].cstruct;
 		size_t i, offset = ctx->share->ClassTable[cid].offset;
 		for(i = 0; i < cs->fsize; i++) {
-			if(cs->fields[i].type == NNTYPE_Int || cs->fields[i].type == NNTYPE_Float || cs->fields[i].type == NNTYPE_Boolean) {
-				continue;
-			}
-			if(cs->fields[i].type == CLASS_unknown) {
+			knh_type_t type = cs->fields[i].type;
+			//DBG2_P("i=%d, fn=%s, type=%s%s", i, FIELDN(cs->fields[i].fn), TYPEQN(type));
+			if(type == NNTYPE_Int || type == NNTYPE_Float ||
+					type == NNTYPE_Boolean || type == TYPE_void) {
 				continue;
 			}
 			if(of->fields[i + offset] == NULL) return; /* for Script */
+			if(cs->fields[i].fn == FIELDN_register) continue;
 			ftr(ctx, of->fields[i + offset]);
 		}
 		cid = ctx->share->ClassTable[cid].supcid;
@@ -1120,16 +1121,18 @@ void knh_ClassStruct_init(Ctx *ctx, ClassStruct *b, int init)
 static
 void knh_ClassStruct_traverse(Ctx *ctx, ClassStruct *b, knh_ftraverse ftr)
 {
+	ftr(ctx, UP(b->methods));
 	if(b->fields != NULL) {
 		knh_intptr_t i;
 		for(i = 0; i < b->fsize; i++) {
 			ftr(ctx, b->fields[i].value);
 		}
 		if(IS_SWEEP(ftr)) {
+			//DBG2_P("freeing b->fields=%p", b->fields);
 			KNH_FREE(ctx, b->fields, b->fsize * sizeof(knh_cfield_t));
+			b->fields = NULL;
 		}
 	}
-	ftr(ctx, UP(b->methods));
 }
 
 /* ======================================================================== */
@@ -2800,8 +2803,10 @@ void konoha_loadFieldNameData(Ctx *ctx, knh_FieldNameData_t *data)
 static
 void konoha_loadMethodFieldData(Ctx *ctx, knh_MethodFieldData_t *data, MethodField **pools)
 {
+	int chk = -1;
 	while(data->mfindex != -1) {
 		DBG2_ASSERT(data->mfindex < KNH_TMETHODFIELD_SIZE);
+		DBG2_ASSERT(data->mfindex > chk); chk = data->mfindex;
 		MethodField *mf = new_MethodField(ctx, data->rtype, data->psize);
 		if(mf->psize == 1) {
 			mf->p0.type = data->t1; mf->p0.fn = data->f1;
@@ -2829,7 +2834,6 @@ void konoha_loadMethodFieldData(Ctx *ctx, knh_MethodFieldData_t *data, MethodFie
 			}
 		}
 		pools[data->mfindex] = mf;
-		konoha_addMethodFieldTable(ctx, mf);
 		data++;
 	}
 }
@@ -2957,6 +2961,10 @@ void konoha_loadSystemData(Ctx *ctx)
 		MethodField *pools[KNH_TMETHODFIELD_SIZE];
 		konoha_loadMethodFieldData(ctx, MethodFieldData, pools);
 		konoha_loadMethodData(ctx, MethodData, pools);
+		int i;
+		for(i = 0; i < KNH_TMETHODFIELD_SIZE; i++) {
+			konoha_addMethodFieldTable(ctx, pools[i]);
+		}
 	}
 	konoha_loadMapperData(ctx, MapperData);
 
