@@ -362,6 +362,12 @@ void knh_ClassStruct_toAbstractAll(Ctx *ctx, ClassStruct *cs)
 			knh_Method_toAbstract(ctx, mtd);
 		}
 	}
+	if(cs->fsize > 0) {
+		size_t i;
+		for(i = 0; i < cs->fsize; i++) {
+			KNH_SETv(ctx, cs->fields[i].value, KNH_NULL);
+		}
+	}
 }
 
 /* ------------------------------------------------------------------------ */
@@ -416,7 +422,6 @@ void konoha_traverseContext0(Ctx *ctx, knh_ftraverse ftr)
 	for(i = 0; i < ctx->share->StructTableSize; i++) {
 		DBG2_ASSERT(ctx->share->ClassTable[i].sname != NULL);
 		ftr(ctx, UP(ctx->share->ClassTable[i].class_cid));
-		ftr(ctx, UP(ctx->share->ClassTable[i].cstruct));
 		ftr(ctx, UP(ctx->share->ClassTable[i].cmap));
 		ftr(ctx, UP(ctx->share->ClassTable[i].cspec));
 		if(ctx->share->ClassTable[i].constPool != NULL) {
@@ -429,12 +434,10 @@ void konoha_traverseContext0(Ctx *ctx, knh_ftraverse ftr)
 			ftr(ctx, UP(ctx->share->ClassTable[i].dataMap));
 		}
 		ftr(ctx, UP(ctx->share->ClassTable[i].lname));
-		ftr(ctx, UP(ctx->share->ClassTable[i].sname));
 	}
 	for(i = ctx->share->ClassTableSize; i < KNH_TCLASS_SIZE; i++) {
 		DBG2_ASSERT(ctx->share->ClassTable[i].sname != NULL);
 		ftr(ctx, UP(ctx->share->ClassTable[i].class_cid));
-		ftr(ctx, UP(ctx->share->ClassTable[i].cstruct));
 		ftr(ctx, UP(ctx->share->ClassTable[i].cmap));
 		ftr(ctx, UP(ctx->share->ClassTable[i].cspec));
 		if(ctx->share->ClassTable[i].constPool != NULL) {
@@ -447,6 +450,16 @@ void konoha_traverseContext0(Ctx *ctx, knh_ftraverse ftr)
 			ftr(ctx, UP(ctx->share->ClassTable[i].dataMap));
 		}
 		ftr(ctx, UP(ctx->share->ClassTable[i].lname));
+	}
+
+	for(i = 0; i < ctx->share->StructTableSize; i++) {
+		DBG2_ASSERT(ctx->share->ClassTable[i].sname != NULL);
+		ftr(ctx, UP(ctx->share->ClassTable[i].cstruct));
+		ftr(ctx, UP(ctx->share->ClassTable[i].sname));
+	}
+	for(i = ctx->share->ClassTableSize; i < KNH_TCLASS_SIZE; i++) {
+		DBG2_ASSERT(ctx->share->ClassTable[i].sname != NULL);
+		ftr(ctx, UP(ctx->share->ClassTable[i].cstruct));
 		ftr(ctx, UP(ctx->share->ClassTable[i].sname));
 	}
 
